@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -35,38 +35,31 @@ CategoryTypeComboBoxTest::~CategoryTypeComboBoxTest()
 
 void CategoryTypeComboBoxTest::shouldHaveDefaultValue()
 {
-    CategoryTypeComboBox w;
-    QCOMPARE(w.count(), 4);
+    CategoryTypeComboBox w(true);
+    QCOMPARE(w.count(), 5);
+
+    CategoryTypeComboBox w2(false);
+    QCOMPARE(w2.count(), 6);
 }
 
 void CategoryTypeComboBoxTest::shouldSetType_data()
 {
-    QTest::addColumn<QString>("input");
+    QTest::addColumn<LoggingCategory::LoggingType>("input");
 
-    QTest::newRow("empty") <<  QString();
-    QTest::newRow("warning") <<  QStringLiteral("warning");
-    QTest::newRow("invalid") <<  QStringLiteral("allss");
-    QTest::newRow("debug") <<  QStringLiteral("debug");
-    QTest::newRow("critical") <<  QStringLiteral("critical");
+    QTest::newRow("all") <<  LoggingCategory::All;
+    QTest::newRow("info") <<  LoggingCategory::Info;
+    QTest::newRow("warning") << LoggingCategory::Warning;
+    QTest::newRow("debug") << LoggingCategory::Debug;
+    QTest::newRow("critical") << LoggingCategory::Critical;
+    QTest::newRow("off") << LoggingCategory::Off;
 }
 
 void CategoryTypeComboBoxTest::shouldSetType()
 {
-    QFETCH(QString, input);
-    CategoryTypeComboBox w;
+    QFETCH(LoggingCategory::LoggingType, input);
+    CategoryTypeComboBox w(false);
     w.setType(input);
-    QString result;
-    if (input.isEmpty()) {
-        result = QStringLiteral("all");
-    }
-    const int pos = w.findData(input);
-    if (pos < 0) {
-        result = QString();
-        QCOMPARE(w.type(), result);
-    } else {
-        result = w.type();
-        QCOMPARE(w.type(), result);
-    }
+    QCOMPARE(w.type(), input);
 }
 
 QTEST_MAIN(CategoryTypeComboBoxTest)
